BpxClient

Struct BpxClient 

pub struct BpxClient { /* private fields */ }
A client for interacting with the Backpack Exchange API.

Implementations

Source

impl BpxClient

pub async fn get_account(&self) -> Result<AccountSettings>

Fetches the account’s settings.

pub async fn get_account_max_borrow( &self, symbol: &str, ) -> Result<AccountMaxBorrow>

Fetches the account’s maximum borrow amount for a given symbol.

pub async fn get_account_max_order( &self, params: MaxOrderQuery, ) -> Result<AccountMaxOrder>

Fetches the account’s maximum order amount for a given symbol.

pub async fn get_account_max_withdrawal( &self, symbol: &str, auto_borrow: Option<bool>, auto_lend_redeem: Option<bool>, ) -> Result<AccountMaxWithdrawal>

Fetches the account’s maximum withdrawal amount for a given symbol.

pub async fn update_account(&self, payload: UpdateAccountPayload) -> Result<()>

Updates the account’s settings.

pub async fn convert_dust_balance( &self, payload: ConvertDustPayload, ) -> Result<()>

Converts a dust balance to USDC. The balance (including lend) must be less than the minimum quantity tradable on the spot order book.

Source

impl BpxClient

pub async fn get_borrow_lend_positions(&self) -> Result<Vec<BorrowLendPosition>>

Retrieves all the open borrow lending positions for the account.

Source

impl BpxClient

pub async fn get_balances(&self) -> Result<HashMap<String, Balance>>

Fetches the account’s current balances.

pub async fn get_deposits( &self, limit: Option<i64>, offset: Option<i64>, ) -> Result<Vec<Deposit>>

Retrieves a list of deposits with optional pagination.

pub async fn get_deposit_address( &self, blockchain: Blockchain, ) -> Result<DepositAddress>

Fetches the deposit address for a specified blockchain.

pub async fn get_withdrawals( &self, limit: Option<i64>, offset: Option<i64>, ) -> Result<Vec<Withdrawal>>

Retrieves a list of withdrawals with optional pagination.

pub async fn request_withdrawal( &self, payload: RequestWithdrawalPayload, ) -> Result<Withdrawal>

Submits a withdrawal request for the specified payload.

pub async fn get_collateral(&self) -> Result<Collateral>

Fetches the subaccount’s collateral information.

Source

impl BpxClient

Source

impl BpxClient

pub async fn get_historical_fills( &self, params: FillsHistoryParams, ) -> Result<Vec<Fill>>

Fetches historical fills with optional filtering and pagination parameters.

Source

impl BpxClient

pub async fn get_assets(&self) -> Result<Vec<Asset>>

Fetches available assets and their associated tokens.

pub async fn get_markets(&self) -> Result<Vec<Market>>

Retrieves a list of available markets.

pub async fn get_all_mark_prices(&self) -> Result<Vec<MarkPrice>>

Retrieves mark price, index price and the funding rate for the current interval for all symbols, or the symbol specified.

pub async fn get_ticker(&self, symbol: &str) -> Result<Ticker>

Fetches the ticker information for a given symbol.

pub async fn get_tickers(&self) -> Result<Vec<Ticker>>

Fetches the ticker information for all symbols.

pub async fn get_order_book_depth( &self, symbol: &str, limit: Option<OrderBookDepthLimit>, ) -> Result<OrderBookDepth>

Retrieves the order book depth for a given symbol.

pub async fn get_funding_interval_rates( &self, symbol: &str, ) -> Result<Vec<FundingRate>>

Funding interval rate history for futures.

pub async fn get_k_lines( &self, symbol: &str, kline_interval: &str, start_time: i64, end_time: Option<i64>, ) -> Result<Vec<Kline>>

Fetches historical K-line (candlestick) data for a given symbol and interval.

Source

impl BpxClient

pub async fn get_open_order( &self, symbol: &str, order_id: Option<&str>, client_id: Option<u32>, ) -> Result<Order>

Fetches a specific open order by symbol and either order ID or client ID.

pub async fn execute_order(&self, payload: ExecuteOrderPayload) -> Result<Order>

Executes a new order with the given payload.

pub async fn cancel_order( &self, symbol: &str, order_id: Option<&str>, client_id: Option<u32>, ) -> Result<Order>

Cancels a specific order by symbol and either order ID or client ID.

pub async fn get_open_orders(&self, symbol: Option<&str>) -> Result<Vec<Order>>

Retrieves all open orders, optionally filtered by symbol.

pub async fn execute_orders( &self, payload: Vec<ExecuteOrderPayload>, ) -> Result<Vec<BatchOrderResponse>>

Executes a new order with the given payload.

pub async fn cancel_open_orders( &self, payload: CancelOpenOrdersPayload, ) -> Result<Vec<Order>>

Cancels all open orders matching the specified payload.

Source

impl BpxClient

pub async fn submit_rfq( &self, payload: RequestForQuotePayload, ) -> Result<RequestForQuote>

pub async fn cancel_rfq( &self, payload: RequestForQuoteCancelPayload, ) -> Result<RequestForQuote>

pub async fn refresh_rfq( &self, payload: RequestForQuoteRefreshPayload, ) -> Result<RequestForQuote>

pub async fn accept_quote( &self, payload: QuoteAcceptPayload, ) -> Result<RequestForQuote>

pub async fn submit_quote(&self, payload: QuotePayload) -> Result<Quote>

pub async fn subscribe_to_rfqs( &self, tx: Sender<RequestForQuoteUpdate>, ) -> Result<()>

Source

impl BpxClient

pub async fn get_recent_trades( &self, symbol: &str, limit: Option<i16>, ) -> Result<Vec<Trade>>

Fetches the most recent trades for a given symbol, with an optional limit.

pub async fn get_historical_trades( &self, symbol: &str, limit: Option<i64>, offset: Option<i64>, ) -> Result<Vec<Trade>>

Fetches historical trades for a given symbol, with optional limit and offset.

Source

impl BpxClient

pub async fn request_two_factor( &self, payload: RequestTwoFactorPayload, ) -> Result<RequestTwoFactorResponse>

Requests a two-factor authentication token.

Sends a request to initiate the two-factor authentication process with the provided payload and returns the response.

Source

impl BpxClient

pub async fn get_vaults(&self) -> Result<Vec<Vault>>

Fetches information about all available vaults on the exchange.

pub async fn vault_mint(&self, request: VaultMintRequest) -> Result<()>

Mints vault tokens by depositing an asset into a vault.

pub async fn vault_redeem(&self, request: VaultRedeemRequest) -> Result<()>

Submits a request to redeem vault tokens for USDC.

pub async fn vault_redeem_cancel( &self, request: VaultRedeemCancelRequest, ) -> Result<()>

Cancels a pending redeem request for a vault.

pub async fn get_vault_pending_redeems( &self, vault_id: u32, ) -> Result<Vec<VaultRedeem>>

Fetches pending redeem requests for a vault.

pub async fn get_vault_history( &self, params: VaultHistoryParams, ) -> Result<Vec<VaultHistory>>

Fetches historical vault data (NAV, equity, circulating supply).

Source

impl BpxClient

pub async fn subscribe<T>(&self, stream: &str, tx: Sender<T>) -> Result<()>
where T: DeserializeOwned + Send + 'static,

Subscribes to a private WebSocket stream and sends messages of type T through a transmitter channel.

pub async fn subscribe_multiple<T>( &self, streams: &[&str], tx: Sender<T>, ) -> Result<()>
where T: DeserializeOwned + Send + 'static,

Subscribes to multiple private WebSocket streams and sends messages of type T through a transmitter channel.

Source

impl BpxClient

pub fn builder() -> BpxClientBuilder

pub fn init( base_url: String, secret: &str, headers: Option<BpxHeaders>, ) -> Result<Self>

Initializes a new client with the given base URL, API secret, and optional headers.

This sets up the signing and verification keys, and creates a reqwest client with default headers including the API key and content type.

pub fn init_with_ws( base_url: String, ws_url: String, secret: &str, headers: Option<BpxHeaders>, ) -> Result<Self>

👎Deprecated: Use BpxClient::builder() instead to configure the client with a custom websocket URL.

Initializes a new client with WebSocket support.

pub async fn get<U: IntoUrl>(&self, url: U) -> Result<Response>

Sends a GET request to the specified URL and signs it before execution.

pub async fn post<P: Serialize, U: IntoUrl>( &self, url: U, payload: P, ) -> Result<Response>

Sends a POST request with a JSON payload to the specified URL and signs it.

pub async fn delete<P: Serialize, U: IntoUrl>( &self, url: U, payload: P, ) -> Result<Response>

Sends a DELETE request with a JSON payload to the specified URL and signs it.

pub async fn patch<P: Serialize, U: IntoUrl>( &self, url: U, payload: P, ) -> Result<Response>

Sends a PATCH request with a JSON payload to the specified URL and signs it.

pub async fn execute(&self, request: Request) -> Result<Response>

pub const fn verifying_key(&self) -> Option<&VerifyingKey>

Returns a reference to the VerifyingKey used for request verification. Return will be Some if the client was initialised with a secret key, otherwise None.

pub const fn client(&self) -> &Client

Returns a reference to the underlying HTTP client.

pub fn base_url(&self) -> &Url

Source

impl BpxClient

pub fn build_signed_request<P: Serialize, U: IntoUrl>( &self, url: U, method: Method, instruction: &str, payload: Option<&P>, ) -> Result<Request>

Builds an authenticated request with signing headers.

Use this to create signed requests for custom endpoints. The instruction must match the Backpack API’s expected instruction string for the endpoint.

Methods from Deref<Target = Client>

pub fn get<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a GET request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn post<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a POST request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn put<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a PUT request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn patch<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a PATCH request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn delete<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a DELETE request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn head<U>(&self, url: U) -> RequestBuilder
where U: IntoUrl,

Convenience method to make a HEAD request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn request<U>(&self, method: Method, url: U) -> RequestBuilder
where U: IntoUrl,

Start building a Request with the Method and Url.

Returns a RequestBuilder, which will allow setting headers and the request body before sending.

Errors

This method fails whenever the supplied Url cannot be parsed.

pub fn execute( &self, request: Request, ) -> impl Future<Output = Result<Response, Error>>

Executes a Request.

A Request can be built manually with Request::new() or obtained from a RequestBuilder with RequestBuilder::build().

You should prefer to use the RequestBuilder and RequestBuilder::send().

Errors

This method fails if there was an error while sending request, redirect loop was detected or redirect limit was exhausted.